%define major     0
%define libname   %mklibname afflib %{major}
%define develname %mklibname afflib -d

Summary:        A set of programs for creating and manipulating AFF files
Name:           afflib
Version:        3.7.10
%define subrel  1
Release:        %mkrel 1
Group:          System/Libraries
License:        BSD
URL:            https://github.com/sshock/AFFLIBv3
Source0:        https://github.com/sshock/AFFLIBv3/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:         CVE-2018-8050.patch

BuildRequires:  pkgconfig(libcurl)
# GPLv2 FOSS incompatible with BSD with advertising
#BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(libewf)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(python2)
# GPLv2 FOSS incompatible with BSD with advertising
#BuildRequires:  readline-devel
BuildRequires:  pkgconfig(zlib)


%description
AFFLIB is an open source library developed by Simson Garfinkel and Basis
Technology that implements the AFF standard. AFFLIB is distributed under
4-clause Berkeley License and may be freely incorporated into both Open
Source and Proprietary software.

In addition to the library, AFFLIB also comes with the AFF Tools, a set of
programs for creating and manipulating AFF files.

%package -n  %{libname}
Summary:     A shared library that implements the AFF standard
Group:       System/Libraries

%description -n	%{libname}
AFFLIB is an open source library developed by Simson Garfinkel and Basis
Technology that implements the AFF standard. AFFLIB is distributed under
4-clause Berkeley License and may be freely incorporated into both Open
Source and Proprietary software.

This package contains a shared library that implements the AFF standard.

%package -n  %{develname}
Summary:     Static library and header files for the afflib library
Group:       Development/C
Provides:    %{name}-devel = %{version}
Requires:    %{libname} = %{version}

%description -n %{develname}
AFFLIB is an open source library developed by Simson Garfinkel and Basis
Technology that implements the AFF standard. AFFLIB is distributed under
4-clause Berkeley License and may be freely incorporated into both Open
Source and Proprietary software.

This package contains the static afflib library and its header files.

%prep
%setup -q -n AFFLIBv3-%{version}
%autopatch -p1

#fix spurious permissions with lzma443
find lzma443 -type f -exec chmod 0644 {} ';'
chmod 0644 lib/base64.{h,cpp}

%build

sh bootstrap.sh

%configure2_5x \
               --disable-static \
               --enable-shared \
               --enable-wide-character-type \
               --enable-libewf=yes \
               --enable-s3=yes \
               --enable-fuse=no \
               --enable-python=yes \
               --enable-qemu=no \
               --with-curl=%{_prefix}

# Remove rpath from libtool
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

# clean unused-direct-shlib-dependencies
sed -i -e 's! -shared ! -Wl,--as-needed\0!g' libtool

%make_build

%install

%make_install

# install headers as well
install -d %{buildroot}%{_includedir}/afflib
install -m0644 lib/*.h %{buildroot}%{_includedir}/afflib/

# we don't want these
find %{buildroot} -name '*.la' -delete

%files
%{_bindir}/affcat
%{_bindir}/affcompare
%{_bindir}/affconvert
%{_bindir}/affcopy
%{_bindir}/affcrypto
%{_bindir}/affdiskprint
%{_bindir}/affix
%{_bindir}/affuse
%{_bindir}/affinfo
%{_bindir}/affrecover
%{_bindir}/affsegment
%{_bindir}/affsign
%{_bindir}/affstats
%{_bindir}/affverify
%{_bindir}/affxml
%{_mandir}/man1/*
%{python2_sitearch}/pyaff.so

%files -n %{libname}
%doc AUTHORS BUGLIST.txt COPYING ChangeLog NEWS README* doc/*
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%dir %{_includedir}/afflib
%{_includedir}/afflib/*.h
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc


%changelog
* Sun Apr 01 2018 daviddavid <daviddavid> 3.7.10-1.1.mga6
  (not released yet)
+ Revision: 1214038
- add upstream patch to fix CVE-2018-8050 (mga#22852)

* Sun Sep 18 2016 daviddavid <daviddavid> 3.7.10-1.mga6
+ Revision: 1053760
- new version: 3.7.10

* Sun Jan 24 2016 daviddavid <daviddavid> 3.7.7-1.mga6
+ Revision: 926944
- new version: 3.7.7
- update URL and Source URL
- use new python macros
- switch BRs to pkgconfig()
- remove unneeded '.la' files

* Wed Oct 15 2014 umeabot <umeabot> 3.7.4-4.mga5
+ Revision: 743482
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.7.4-3.mga5
+ Revision: 686459
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 3.7.4-2.mga5
+ Revision: 677712
- Mageia 5 Mass Rebuild

* Sat Jun 21 2014 malo <malo> 3.7.4-1.mga5
+ Revision: 638250
- update to 3.7.4

* Fri Oct 18 2013 umeabot <umeabot> 3.7.1-3.mga4
+ Revision: 502464
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 3.7.1-2.mga3
+ Revision: 345321
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Jun 07 2012 malo <malo> 3.7.1-1.mga3
+ Revision: 257142
- new version 3.7.1

* Mon Apr 02 2012 pterjan <pterjan> 3.6.15-2.mga2
+ Revision: 227773
- Rebuild after libexpat.la removal

* Tue Jan 31 2012 malo <malo> 3.6.15-1.mga2
+ Revision: 203595
- update to version 3.6.15
- remove the warning disabling

* Sun Jan 29 2012 malo <malo> 3.6.6-1.mga2
+ Revision: 202761
- adaptation after import from Mandriva
- new version 3.6.6
- imported package afflib

